@@ -441,8 +441,8 @@ use L2hos;
 use vars qw(%prefs %cfg %newcfg);
 
 # This is the central place to modify the release name and date!!!
-my $RELEASE = '2021.2';
-my $VERSION = 'Released July 1, 2021';
+my $RELEASE = '2022.2';
+my $VERSION = 'Released July 1, 2022';
 
 # --------------------------------------------------------------------------
 # Open log
@@ -898,6 +898,16 @@ if($kpsewhich) {
   }
 }
 
+if ($kpsewhich) {
+    &checking('for preview.sty');
+    my ($stat,$out,$err) = &get_out_err("$kpsewhich preview.sty");
+    if($stat == 0) { # ok
+	&result("ok");
+    } else {
+	&logit("NONE\nWarning: preview.sty not found.\n         svg images will not work.\n         dvipng will not work\n");
+    }
+}
+
 &checking('for TeX include path');
 my $texpath = $opt{TEXPATH} || $prefs{TEXPATH} || '';
 if($texpath eq 'no') {
